@@ -62,15 +62,15 @@ noop_renderer_resize_output(struct weston_output *output,
 }
 
 static void
-noop_renderer_flush_damage(struct weston_surface *surface,
-			   struct weston_buffer *buffer,
-			   struct weston_output *output)
+noop_renderer_flush_damage(struct weston_paint_node *pnode)
 {
 }
 
 static void
-noop_renderer_attach(struct weston_surface *es, struct weston_buffer *buffer)
+noop_renderer_attach(struct weston_paint_node *pnode)
 {
+	struct weston_surface *es = pnode->surface;
+	struct weston_buffer *buffer = es->buffer_ref.buffer;
 	struct noop_renderer *renderer =
 		wl_container_of(es->compositor->renderer, renderer, base);
 	struct wl_shm_buffer *shm_buffer;
@@ -95,7 +95,7 @@ noop_renderer_attach(struct weston_surface *es, struct weston_buffer *buffer)
 
 	shm_buffer = buffer->shm_buffer;
 	data = wl_shm_buffer_get_data(shm_buffer);
-	stride = wl_shm_buffer_get_stride(shm_buffer);
+	stride = buffer->stride;
 	height = buffer->height;
 	size = stride * height;
 
